==> mansiki0.09_20081009.zip: Mansiki-FileIO.scm <==
; GIMP Script-Fu Mansiki Libs
;Tiny-fu版に変更
(define ( Mansiki-FileIO ) 
	(gimp-message  "FileIO")
	
)

;--------------------------------------------------指定ファイルにリストのデータを\n区切りで書き込み(上書き)
(define ( MSK-WriteOut fileName detaList) 
	(let* (
			(listLength (length  detaList))
			(outfile (list ""))
			(count 0)
			(fileHandlerWO (open-output-file fileName ))
		)	
		(if (and    (not (null? fileName))
		            (string? fileName)
		            (> (string-length fileName) 0)
		      )
	        (begin 
	            ;(set! fileHandlerWO (open-output-file fileName ));fwrite置き換えです
	             (while (< (+ count 1) listLength)
                    (display (string-append (MSK-getValueByIndex detaList count) "\n" ) fileHandlerWO);write
                    (set! count (+ count 1))
                 )
                (display (MSK-getValueByIndex detaList count) fileHandlerWO)
                (close-output-port fileHandlerWO);fclose
                TRUE
	        )
	        (begin 
                (close-output-port fileHandlerWO);fclose
		    	FALSE
		    )
		)
	)
)
;--------------------------------------------------指定ファイルにリストのデータを\n区切りで書き込み(追記)
(define ( MSK-WriteAdd fileName detaList) 
	(let* (
			(listLength (length  detaList))
			(tempList  ( MSK-ReadIn fileName))
			(count 0)
		)	
		(set! tempList (append tempList detaList))
        ( MSK-WriteOut fileName tempList) 
	)
)
;--------------------------------------------------指定ファイルにリストのデータを\n区切りで書き込み
(define ( MSK-Write FileHandle massage) 
    (display massage FileHandle)
 )
;--------------------------------------------------読み込み
(define ( MSK-ReadIn fileName) 
	(let* (
			(tempString "")
			(outfile (list ""))
			( fileHandlerRI (open-input-file fileName ))
			( fileHandlerWO "")
		)	
		(if (and    (not (null? fileName))
		            (string? fileName)
		            (> (string-length fileName) 0)
		      )
		      (begin
		        (if (eqv? ( MSK-existTheFile fileName) TRUE) 
                    (begin
                        (set! tempString (MSK-fread fileHandlerRI ));Max 32bit -1?(2GB?)"2147483647" 1
                        (close-input-port fileHandlerRI)
                            
                        (if(null? tempString)
                            (set! tempString fileName)
                        )
        	            (if(equal? tempString "")
        	               (set! tempString "empty")
        	            )
        	            (MSK-split tempString "\n")
    	            )
		            (begin 
                        (set! fileHandlerWO (open-output-file fileName ))
                        (close-output-port fileHandlerWO)
                        ;outfile
                        (MSK-push outfile fileName)
                    )
		        )
            )
		)
	)
)

;--------------------------------------------------元のfreadの仕様が意味不明なので自作メソッドへ
(define (MSK-fread file-port)
    (let (
         (str "")
         (c)
         (count 2147483647)
         )

      (while (> count 0)
        (set! count (- count 1))
        (set! c (read-char file-port))
        (if (eof-object? c)
            (set! count 0)
            (set! str (string-append str (MSK-char2String c)))
        )
      )

      (if (eqv? str "")
          ()
          str
      )
    )
)
;--------------------------------------------------指定のファイルがあるかを確認
(define ( MSK-existTheFile fileName) 
	(let* (
			(listLength (length  (MSK-getValueByIndex (file-glob fileName 1) 1)))
		)	
	    (if(> listLength 0)
		    TRUE
		   FALSE
	    )
	)
)
;--------------------------------------------------指定のファイルがあるかを確認
(define ( MSK-getCurrentPath fileName) 
	(let* (
			(tempString "test")
		)	
		    ( MSK-WriteOut "test.txt" (list ""))
		tempString
	)
)
;--------------------------------------------------
(script-fu-register "Mansiki-FileIO"
		    "Mansiki-FileIO(Lib)"
		    "Mansiki"
		    "name"
		    "copyright"
		    "2007/05/27"
		    "GPL"
	) 

(script-fu-menu-register "Mansiki-FileIO"
		    "<Toolbox>/Xtns/Script-Fu/Mansiki")

==> mansiki0.10_20081105.zip: Mansiki-FileIO.scm <==
; GIMP Script-Fu Mansiki Libs
;Tiny-fu版に変更
(define ( Mansiki-FileIO ) 
	(gimp-message  "FileIO")
	
)

;--------------------------------------------------指定ファイルにリストのデータを\n区切りで書き込み(上書き)
(define ( MSK-WriteOut fileName detaList) 
	(let* (
			(listLength (length  detaList))
			(outfile (list ""))
			(count 0)
			(fileHandlerWO (open-output-file fileName ))
		)	
		(if (and    (not (null? fileName))
		            (string? fileName)
		            (> (string-length fileName) 0)
		      )
	        (begin 
	            ;(set! fileHandlerWO (open-output-file fileName ));fwrite置き換えです
	             (while (< (+ count 1) listLength)
                    (display (string-append (MSK-getValueByIndex detaList count) "\n" ) fileHandlerWO);write
                    (set! count (+ count 1))
                 )
                (display (MSK-getValueByIndex detaList count) fileHandlerWO)
                (close-output-port fileHandlerWO);fclose
                TRUE
	        )
	        (begin 
                (close-output-port fileHandlerWO);fclose
		    	FALSE
		    )
		)
	)
)
;--------------------------------------------------指定ファイルにリストのデータを\n区切りで書き込み(追記)
(define ( MSK-WriteAdd fileName detaList) 
	(let* (
			(listLength (length  detaList))
			(tempList  ( MSK-ReadIn fileName))
			(count 0)
		)	
		(set! tempList (append tempList detaList))
        ( MSK-WriteOut fileName tempList) 
	)
)
;--------------------------------------------------指定ファイルにリストのデータを\n区切りで書き込み
(define ( MSK-Write FileHandle massage) 
    (display massage FileHandle)
 )
;--------------------------------------------------読み込み
(define ( MSK-ReadIn fileName) 
	(let* (
			(tempString "")
			(outfile (list ""))
			( fileHandlerRI (open-input-file fileName ))
			( fileHandlerWO "")
		)	
		(if (and    (not (null? fileName))
		            (string? fileName)
		            (> (string-length fileName) 0)
		      )
		      (begin
		        (if (eqv? ( MSK-existTheFile fileName) TRUE) 
                    (begin
                        (set! tempString (MSK-fread fileHandlerRI ));Max 32bit -1?(2GB?)"2147483647" 1
                        (close-input-port fileHandlerRI)
                            
                        (if(null? tempString)
                            (set! tempString fileName)
                        )
        	            (if(equal? tempString "")
        	               (set! tempString "empty")
        	            )
        	            (MSK-split tempString "\n")
    	            )
		            (begin 
                        (set! fileHandlerWO (open-output-file fileName ))
                        (close-output-port fileHandlerWO)
                        ;outfile
                        (MSK-push outfile fileName)
                    )
		        )
            )
		)
	)
)

;--------------------------------------------------元のfreadの仕様が意味不明なので自作メソッドへ
(define (MSK-fread file-port)
    (let (
         (str "")
         (d 0)
         (count 2147483647)
         )

      (while (> count 0)
        (set! count (- count 1))
        (set! d (read-char file-port))
        (if (eof-object? d)
            (set! count 0)
            (set! str (string-append str (MSK-char2String d)))
        )
      )

      (if (eqv? str "")
          ()
          str
      )
    )
)
;--------------------------------------------------指定のファイルがあるかを確認
(define ( MSK-existTheFile fileName) 
	(let* (
			(listLength (length  (MSK-getValueByIndex (file-glob fileName 1) 1)))
		)	
	    (if(> listLength 0)
		    TRUE
		   FALSE
	    )
	)
)
;--------------------------------------------------指定のファイルがあるかを確認
(define ( MSK-getCurrentPath fileName) 
	(let* (
			(tempString "test")
		)	
		    ( MSK-WriteOut "test.txt" (list ""))
		tempString
	)
)
;--------------------------------------------------
(script-fu-register "Mansiki-FileIO"
		    "Mansiki-FileIO(Lib)"
		    "Mansiki"
		    "name"
		    "copyright"
		    "2007/05/27"
		    "GPL"
	) 

(script-fu-menu-register "Mansiki-FileIO"
		    "<Toolbox>/Xtns/Script-Fu/Mansiki")
